from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.check_type import CheckType
from ...models.table_list_model import TableListModel
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    connection: Union[Unset, None, str] = UNSET,
    schema: Union[Unset, None, str] = UNSET,
    table: Union[Unset, None, str] = UNSET,
    label: Union[Unset, None, List[str]] = UNSET,
    page: Union[Unset, None, int] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    check_type: Union[Unset, None, CheckType] = UNSET,
) -> Dict[str, Any]:
    pass

    params: Dict[str, Any] = {}
    params["connection"] = connection

    params["schema"] = schema

    params["table"] = table

    json_label: Union[Unset, None, List[str]] = UNSET
    if not isinstance(label, Unset):
        if label is None:
            json_label = None
        else:
            json_label = label

    params["label"] = json_label

    params["page"] = page

    params["limit"] = limit

    json_check_type: Union[Unset, None, str] = UNSET
    if not isinstance(check_type, Unset):
        json_check_type = check_type.value if check_type else None

    params["checkType"] = json_check_type

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": "api/search/tables",
        "params": params,
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[List["TableListModel"]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = TableListModel.from_dict(response_200_item_data)

            response_200.append(response_200_item)

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[List["TableListModel"]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    connection: Union[Unset, None, str] = UNSET,
    schema: Union[Unset, None, str] = UNSET,
    table: Union[Unset, None, str] = UNSET,
    label: Union[Unset, None, List[str]] = UNSET,
    page: Union[Unset, None, int] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    check_type: Union[Unset, None, CheckType] = UNSET,
) -> Response[List["TableListModel"]]:
    """findTables

     Finds tables in any data source and schema

    Args:
        connection (Union[Unset, None, str]):
        schema (Union[Unset, None, str]):
        table (Union[Unset, None, str]):
        label (Union[Unset, None, List[str]]):
        page (Union[Unset, None, int]):
        limit (Union[Unset, None, int]):
        check_type (Union[Unset, None, CheckType]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['TableListModel']]
    """

    kwargs = _get_kwargs(
        connection=connection,
        schema=schema,
        table=table,
        label=label,
        page=page,
        limit=limit,
        check_type=check_type,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient,
    connection: Union[Unset, None, str] = UNSET,
    schema: Union[Unset, None, str] = UNSET,
    table: Union[Unset, None, str] = UNSET,
    label: Union[Unset, None, List[str]] = UNSET,
    page: Union[Unset, None, int] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    check_type: Union[Unset, None, CheckType] = UNSET,
) -> Optional[List["TableListModel"]]:
    """findTables

     Finds tables in any data source and schema

    Args:
        connection (Union[Unset, None, str]):
        schema (Union[Unset, None, str]):
        table (Union[Unset, None, str]):
        label (Union[Unset, None, List[str]]):
        page (Union[Unset, None, int]):
        limit (Union[Unset, None, int]):
        check_type (Union[Unset, None, CheckType]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        List['TableListModel']
    """

    return sync_detailed(
        client=client,
        connection=connection,
        schema=schema,
        table=table,
        label=label,
        page=page,
        limit=limit,
        check_type=check_type,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    connection: Union[Unset, None, str] = UNSET,
    schema: Union[Unset, None, str] = UNSET,
    table: Union[Unset, None, str] = UNSET,
    label: Union[Unset, None, List[str]] = UNSET,
    page: Union[Unset, None, int] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    check_type: Union[Unset, None, CheckType] = UNSET,
) -> Response[List["TableListModel"]]:
    """findTables

     Finds tables in any data source and schema

    Args:
        connection (Union[Unset, None, str]):
        schema (Union[Unset, None, str]):
        table (Union[Unset, None, str]):
        label (Union[Unset, None, List[str]]):
        page (Union[Unset, None, int]):
        limit (Union[Unset, None, int]):
        check_type (Union[Unset, None, CheckType]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['TableListModel']]
    """

    kwargs = _get_kwargs(
        connection=connection,
        schema=schema,
        table=table,
        label=label,
        page=page,
        limit=limit,
        check_type=check_type,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    connection: Union[Unset, None, str] = UNSET,
    schema: Union[Unset, None, str] = UNSET,
    table: Union[Unset, None, str] = UNSET,
    label: Union[Unset, None, List[str]] = UNSET,
    page: Union[Unset, None, int] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    check_type: Union[Unset, None, CheckType] = UNSET,
) -> Optional[List["TableListModel"]]:
    """findTables

     Finds tables in any data source and schema

    Args:
        connection (Union[Unset, None, str]):
        schema (Union[Unset, None, str]):
        table (Union[Unset, None, str]):
        label (Union[Unset, None, List[str]]):
        page (Union[Unset, None, int]):
        limit (Union[Unset, None, int]):
        check_type (Union[Unset, None, CheckType]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        List['TableListModel']
    """

    return (
        await asyncio_detailed(
            client=client,
            connection=connection,
            schema=schema,
            table=table,
            label=label,
            page=page,
            limit=limit,
            check_type=check_type,
        )
    ).parsed



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_date_in_range_percent_check_spec import (
        ColumnDateInRangePercentCheckSpec,
    )
    from ..models.column_date_values_in_future_percent_check_spec import (
        ColumnDateValuesInFuturePercentCheckSpec,
    )
    from ..models.column_datetime_daily_partitioned_checks_spec_custom_checks import (
        ColumnDatetimeDailyPartitionedChecksSpecCustomChecks,
    )
    from ..models.column_text_match_date_format_percent_check_spec import (
        ColumnTextMatchDateFormatPercentCheckSpec,
    )


T = TypeVar("T", bound="ColumnDatetimeDailyPartitionedChecksSpec")


@_attrs_define
class ColumnDatetimeDailyPartitionedChecksSpec:
    """
    Attributes:
        custom_checks (Union[Unset, ColumnDatetimeDailyPartitionedChecksSpecCustomChecks]): Dictionary of additional
            custom checks within this category. The keys are check names defined in the definition section. The sensor
            parameters and rules should match the type of the configured sensor and rule for the custom check.
        daily_partition_date_values_in_future_percent (Union[Unset, ColumnDateValuesInFuturePercentCheckSpec]):
        daily_partition_date_in_range_percent (Union[Unset, ColumnDateInRangePercentCheckSpec]):
        daily_partition_text_match_date_format_percent (Union[Unset, ColumnTextMatchDateFormatPercentCheckSpec]):
    """

    custom_checks: Union[
        Unset, "ColumnDatetimeDailyPartitionedChecksSpecCustomChecks"
    ] = UNSET
    daily_partition_date_values_in_future_percent: Union[
        Unset, "ColumnDateValuesInFuturePercentCheckSpec"
    ] = UNSET
    daily_partition_date_in_range_percent: Union[
        Unset, "ColumnDateInRangePercentCheckSpec"
    ] = UNSET
    daily_partition_text_match_date_format_percent: Union[
        Unset, "ColumnTextMatchDateFormatPercentCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_checks, Unset):
            custom_checks = self.custom_checks.to_dict()

        daily_partition_date_values_in_future_percent: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.daily_partition_date_values_in_future_percent, Unset):
            daily_partition_date_values_in_future_percent = (
                self.daily_partition_date_values_in_future_percent.to_dict()
            )

        daily_partition_date_in_range_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_partition_date_in_range_percent, Unset):
            daily_partition_date_in_range_percent = (
                self.daily_partition_date_in_range_percent.to_dict()
            )

        daily_partition_text_match_date_format_percent: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.daily_partition_text_match_date_format_percent, Unset):
            daily_partition_text_match_date_format_percent = (
                self.daily_partition_text_match_date_format_percent.to_dict()
            )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom_checks is not UNSET:
            field_dict["custom_checks"] = custom_checks
        if daily_partition_date_values_in_future_percent is not UNSET:
            field_dict[
                "daily_partition_date_values_in_future_percent"
            ] = daily_partition_date_values_in_future_percent
        if daily_partition_date_in_range_percent is not UNSET:
            field_dict[
                "daily_partition_date_in_range_percent"
            ] = daily_partition_date_in_range_percent
        if daily_partition_text_match_date_format_percent is not UNSET:
            field_dict[
                "daily_partition_text_match_date_format_percent"
            ] = daily_partition_text_match_date_format_percent

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_date_in_range_percent_check_spec import (
            ColumnDateInRangePercentCheckSpec,
        )
        from ..models.column_date_values_in_future_percent_check_spec import (
            ColumnDateValuesInFuturePercentCheckSpec,
        )
        from ..models.column_datetime_daily_partitioned_checks_spec_custom_checks import (
            ColumnDatetimeDailyPartitionedChecksSpecCustomChecks,
        )
        from ..models.column_text_match_date_format_percent_check_spec import (
            ColumnTextMatchDateFormatPercentCheckSpec,
        )

        d = src_dict.copy()
        _custom_checks = d.pop("custom_checks", UNSET)
        custom_checks: Union[
            Unset, ColumnDatetimeDailyPartitionedChecksSpecCustomChecks
        ]
        if isinstance(_custom_checks, Unset):
            custom_checks = UNSET
        else:
            custom_checks = (
                ColumnDatetimeDailyPartitionedChecksSpecCustomChecks.from_dict(
                    _custom_checks
                )
            )

        _daily_partition_date_values_in_future_percent = d.pop(
            "daily_partition_date_values_in_future_percent", UNSET
        )
        daily_partition_date_values_in_future_percent: Union[
            Unset, ColumnDateValuesInFuturePercentCheckSpec
        ]
        if isinstance(_daily_partition_date_values_in_future_percent, Unset):
            daily_partition_date_values_in_future_percent = UNSET
        else:
            daily_partition_date_values_in_future_percent = (
                ColumnDateValuesInFuturePercentCheckSpec.from_dict(
                    _daily_partition_date_values_in_future_percent
                )
            )

        _daily_partition_date_in_range_percent = d.pop(
            "daily_partition_date_in_range_percent", UNSET
        )
        daily_partition_date_in_range_percent: Union[
            Unset, ColumnDateInRangePercentCheckSpec
        ]
        if isinstance(_daily_partition_date_in_range_percent, Unset):
            daily_partition_date_in_range_percent = UNSET
        else:
            daily_partition_date_in_range_percent = (
                ColumnDateInRangePercentCheckSpec.from_dict(
                    _daily_partition_date_in_range_percent
                )
            )

        _daily_partition_text_match_date_format_percent = d.pop(
            "daily_partition_text_match_date_format_percent", UNSET
        )
        daily_partition_text_match_date_format_percent: Union[
            Unset, ColumnTextMatchDateFormatPercentCheckSpec
        ]
        if isinstance(_daily_partition_text_match_date_format_percent, Unset):
            daily_partition_text_match_date_format_percent = UNSET
        else:
            daily_partition_text_match_date_format_percent = (
                ColumnTextMatchDateFormatPercentCheckSpec.from_dict(
                    _daily_partition_text_match_date_format_percent
                )
            )

        column_datetime_daily_partitioned_checks_spec = cls(
            custom_checks=custom_checks,
            daily_partition_date_values_in_future_percent=daily_partition_date_values_in_future_percent,
            daily_partition_date_in_range_percent=daily_partition_date_in_range_percent,
            daily_partition_text_match_date_format_percent=daily_partition_text_match_date_format_percent,
        )

        column_datetime_daily_partitioned_checks_spec.additional_properties = d
        return column_datetime_daily_partitioned_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.incident_status import IncidentStatus
from ...types import UNSET, Response


def _get_kwargs(
    connection_name: str,
    year: int,
    month: int,
    incident_id: str,
    *,
    status: IncidentStatus,
) -> Dict[str, Any]:
    pass

    params: Dict[str, Any] = {}
    json_status = status.value

    params["status"] = json_status

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "post",
        "url": "api/incidents/{connectionName}/{year}/{month}/{incidentId}/status".format(
            connectionName=connection_name,
            year=year,
            month=month,
            incidentId=incident_id,
        ),
        "params": params,
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Any]:
    if response.status_code == HTTPStatus.NO_CONTENT:
        return None
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Any]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    connection_name: str,
    year: int,
    month: int,
    incident_id: str,
    *,
    client: AuthenticatedClient,
    status: IncidentStatus,
) -> Response[Any]:
    """setIncidentStatus

     Changes the incident's status to a new status.

    Args:
        connection_name (str):
        year (int):
        month (int):
        incident_id (str):
        status (IncidentStatus):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        connection_name=connection_name,
        year=year,
        month=month,
        incident_id=incident_id,
        status=status,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


async def asyncio_detailed(
    connection_name: str,
    year: int,
    month: int,
    incident_id: str,
    *,
    client: AuthenticatedClient,
    status: IncidentStatus,
) -> Response[Any]:
    """setIncidentStatus

     Changes the incident's status to a new status.

    Args:
        connection_name (str):
        year (int):
        month (int):
        incident_id (str):
        status (IncidentStatus):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        connection_name=connection_name,
        year=year,
        month=month,
        incident_id=incident_id,
        status=status,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_accuracy_monthly_monitoring_checks_spec_custom_checks import (
        ColumnAccuracyMonthlyMonitoringChecksSpecCustomChecks,
    )
    from ..models.column_accuracy_total_average_match_percent_check_spec import (
        ColumnAccuracyTotalAverageMatchPercentCheckSpec,
    )
    from ..models.column_accuracy_total_max_match_percent_check_spec import (
        ColumnAccuracyTotalMaxMatchPercentCheckSpec,
    )
    from ..models.column_accuracy_total_min_match_percent_check_spec import (
        ColumnAccuracyTotalMinMatchPercentCheckSpec,
    )
    from ..models.column_accuracy_total_not_null_count_match_percent_check_spec import (
        ColumnAccuracyTotalNotNullCountMatchPercentCheckSpec,
    )
    from ..models.column_accuracy_total_sum_match_percent_check_spec import (
        ColumnAccuracyTotalSumMatchPercentCheckSpec,
    )


T = TypeVar("T", bound="ColumnAccuracyMonthlyMonitoringChecksSpec")


@_attrs_define
class ColumnAccuracyMonthlyMonitoringChecksSpec:
    """
    Attributes:
        custom_checks (Union[Unset, ColumnAccuracyMonthlyMonitoringChecksSpecCustomChecks]): Dictionary of additional
            custom checks within this category. The keys are check names defined in the definition section. The sensor
            parameters and rules should match the type of the configured sensor and rule for the custom check.
        monthly_total_sum_match_percent (Union[Unset, ColumnAccuracyTotalSumMatchPercentCheckSpec]):
        monthly_total_min_match_percent (Union[Unset, ColumnAccuracyTotalMinMatchPercentCheckSpec]):
        monthly_total_max_match_percent (Union[Unset, ColumnAccuracyTotalMaxMatchPercentCheckSpec]):
        monthly_total_average_match_percent (Union[Unset, ColumnAccuracyTotalAverageMatchPercentCheckSpec]):
        monthly_total_not_null_count_match_percent (Union[Unset, ColumnAccuracyTotalNotNullCountMatchPercentCheckSpec]):
    """

    custom_checks: Union[
        Unset, "ColumnAccuracyMonthlyMonitoringChecksSpecCustomChecks"
    ] = UNSET
    monthly_total_sum_match_percent: Union[
        Unset, "ColumnAccuracyTotalSumMatchPercentCheckSpec"
    ] = UNSET
    monthly_total_min_match_percent: Union[
        Unset, "ColumnAccuracyTotalMinMatchPercentCheckSpec"
    ] = UNSET
    monthly_total_max_match_percent: Union[
        Unset, "ColumnAccuracyTotalMaxMatchPercentCheckSpec"
    ] = UNSET
    monthly_total_average_match_percent: Union[
        Unset, "ColumnAccuracyTotalAverageMatchPercentCheckSpec"
    ] = UNSET
    monthly_total_not_null_count_match_percent: Union[
        Unset, "ColumnAccuracyTotalNotNullCountMatchPercentCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_checks, Unset):
            custom_checks = self.custom_checks.to_dict()

        monthly_total_sum_match_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_total_sum_match_percent, Unset):
            monthly_total_sum_match_percent = (
                self.monthly_total_sum_match_percent.to_dict()
            )

        monthly_total_min_match_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_total_min_match_percent, Unset):
            monthly_total_min_match_percent = (
                self.monthly_total_min_match_percent.to_dict()
            )

        monthly_total_max_match_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_total_max_match_percent, Unset):
            monthly_total_max_match_percent = (
                self.monthly_total_max_match_percent.to_dict()
            )

        monthly_total_average_match_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_total_average_match_percent, Unset):
            monthly_total_average_match_percent = (
                self.monthly_total_average_match_percent.to_dict()
            )

        monthly_total_not_null_count_match_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_total_not_null_count_match_percent, Unset):
            monthly_total_not_null_count_match_percent = (
                self.monthly_total_not_null_count_match_percent.to_dict()
            )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom_checks is not UNSET:
            field_dict["custom_checks"] = custom_checks
        if monthly_total_sum_match_percent is not UNSET:
            field_dict[
                "monthly_total_sum_match_percent"
            ] = monthly_total_sum_match_percent
        if monthly_total_min_match_percent is not UNSET:
            field_dict[
                "monthly_total_min_match_percent"
            ] = monthly_total_min_match_percent
        if monthly_total_max_match_percent is not UNSET:
            field_dict[
                "monthly_total_max_match_percent"
            ] = monthly_total_max_match_percent
        if monthly_total_average_match_percent is not UNSET:
            field_dict[
                "monthly_total_average_match_percent"
            ] = monthly_total_average_match_percent
        if monthly_total_not_null_count_match_percent is not UNSET:
            field_dict[
                "monthly_total_not_null_count_match_percent"
            ] = monthly_total_not_null_count_match_percent

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_accuracy_monthly_monitoring_checks_spec_custom_checks import (
            ColumnAccuracyMonthlyMonitoringChecksSpecCustomChecks,
        )
        from ..models.column_accuracy_total_average_match_percent_check_spec import (
            ColumnAccuracyTotalAverageMatchPercentCheckSpec,
        )
        from ..models.column_accuracy_total_max_match_percent_check_spec import (
            ColumnAccuracyTotalMaxMatchPercentCheckSpec,
        )
        from ..models.column_accuracy_total_min_match_percent_check_spec import (
            ColumnAccuracyTotalMinMatchPercentCheckSpec,
        )
        from ..models.column_accuracy_total_not_null_count_match_percent_check_spec import (
            ColumnAccuracyTotalNotNullCountMatchPercentCheckSpec,
        )
        from ..models.column_accuracy_total_sum_match_percent_check_spec import (
            ColumnAccuracyTotalSumMatchPercentCheckSpec,
        )

        d = src_dict.copy()
        _custom_checks = d.pop("custom_checks", UNSET)
        custom_checks: Union[
            Unset, ColumnAccuracyMonthlyMonitoringChecksSpecCustomChecks
        ]
        if isinstance(_custom_checks, Unset):
            custom_checks = UNSET
        else:
            custom_checks = (
                ColumnAccuracyMonthlyMonitoringChecksSpecCustomChecks.from_dict(
                    _custom_checks
                )
            )

        _monthly_total_sum_match_percent = d.pop(
            "monthly_total_sum_match_percent", UNSET
        )
        monthly_total_sum_match_percent: Union[
            Unset, ColumnAccuracyTotalSumMatchPercentCheckSpec
        ]
        if isinstance(_monthly_total_sum_match_percent, Unset):
            monthly_total_sum_match_percent = UNSET
        else:
            monthly_total_sum_match_percent = (
                ColumnAccuracyTotalSumMatchPercentCheckSpec.from_dict(
                    _monthly_total_sum_match_percent
                )
            )

        _monthly_total_min_match_percent = d.pop(
            "monthly_total_min_match_percent", UNSET
        )
        monthly_total_min_match_percent: Union[
            Unset, ColumnAccuracyTotalMinMatchPercentCheckSpec
        ]
        if isinstance(_monthly_total_min_match_percent, Unset):
            monthly_total_min_match_percent = UNSET
        else:
            monthly_total_min_match_percent = (
                ColumnAccuracyTotalMinMatchPercentCheckSpec.from_dict(
                    _monthly_total_min_match_percent
                )
            )

        _monthly_total_max_match_percent = d.pop(
            "monthly_total_max_match_percent", UNSET
        )
        monthly_total_max_match_percent: Union[
            Unset, ColumnAccuracyTotalMaxMatchPercentCheckSpec
        ]
        if isinstance(_monthly_total_max_match_percent, Unset):
            monthly_total_max_match_percent = UNSET
        else:
            monthly_total_max_match_percent = (
                ColumnAccuracyTotalMaxMatchPercentCheckSpec.from_dict(
                    _monthly_total_max_match_percent
                )
            )

        _monthly_total_average_match_percent = d.pop(
            "monthly_total_average_match_percent", UNSET
        )
        monthly_total_average_match_percent: Union[
            Unset, ColumnAccuracyTotalAverageMatchPercentCheckSpec
        ]
        if isinstance(_monthly_total_average_match_percent, Unset):
            monthly_total_average_match_percent = UNSET
        else:
            monthly_total_average_match_percent = (
                ColumnAccuracyTotalAverageMatchPercentCheckSpec.from_dict(
                    _monthly_total_average_match_percent
                )
            )

        _monthly_total_not_null_count_match_percent = d.pop(
            "monthly_total_not_null_count_match_percent", UNSET
        )
        monthly_total_not_null_count_match_percent: Union[
            Unset, ColumnAccuracyTotalNotNullCountMatchPercentCheckSpec
        ]
        if isinstance(_monthly_total_not_null_count_match_percent, Unset):
            monthly_total_not_null_count_match_percent = UNSET
        else:
            monthly_total_not_null_count_match_percent = (
                ColumnAccuracyTotalNotNullCountMatchPercentCheckSpec.from_dict(
                    _monthly_total_not_null_count_match_percent
                )
            )

        column_accuracy_monthly_monitoring_checks_spec = cls(
            custom_checks=custom_checks,
            monthly_total_sum_match_percent=monthly_total_sum_match_percent,
            monthly_total_min_match_percent=monthly_total_min_match_percent,
            monthly_total_max_match_percent=monthly_total_max_match_percent,
            monthly_total_average_match_percent=monthly_total_average_match_percent,
            monthly_total_not_null_count_match_percent=monthly_total_not_null_count_match_percent,
        )

        column_accuracy_monthly_monitoring_checks_spec.additional_properties = d
        return column_accuracy_monthly_monitoring_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.table_custom_sql_profiling_checks_spec_custom_checks import (
        TableCustomSqlProfilingChecksSpecCustomChecks,
    )
    from ..models.table_sql_aggregate_expression_check_spec import (
        TableSqlAggregateExpressionCheckSpec,
    )
    from ..models.table_sql_condition_failed_check_spec import (
        TableSqlConditionFailedCheckSpec,
    )
    from ..models.table_sql_condition_passed_percent_check_spec import (
        TableSqlConditionPassedPercentCheckSpec,
    )
    from ..models.table_sql_import_custom_result_check_spec import (
        TableSqlImportCustomResultCheckSpec,
    )


T = TypeVar("T", bound="TableCustomSqlProfilingChecksSpec")


@_attrs_define
class TableCustomSqlProfilingChecksSpec:
    """
    Attributes:
        custom_checks (Union[Unset, TableCustomSqlProfilingChecksSpecCustomChecks]): Dictionary of additional custom
            checks within this category. The keys are check names defined in the definition section. The sensor parameters
            and rules should match the type of the configured sensor and rule for the custom check.
        profile_sql_condition_failed_on_table (Union[Unset, TableSqlConditionFailedCheckSpec]):
        profile_sql_condition_passed_percent_on_table (Union[Unset, TableSqlConditionPassedPercentCheckSpec]):
        profile_sql_aggregate_expression_on_table (Union[Unset, TableSqlAggregateExpressionCheckSpec]):
        profile_import_custom_result_on_table (Union[Unset, TableSqlImportCustomResultCheckSpec]):
    """

    custom_checks: Union[Unset, "TableCustomSqlProfilingChecksSpecCustomChecks"] = UNSET
    profile_sql_condition_failed_on_table: Union[
        Unset, "TableSqlConditionFailedCheckSpec"
    ] = UNSET
    profile_sql_condition_passed_percent_on_table: Union[
        Unset, "TableSqlConditionPassedPercentCheckSpec"
    ] = UNSET
    profile_sql_aggregate_expression_on_table: Union[
        Unset, "TableSqlAggregateExpressionCheckSpec"
    ] = UNSET
    profile_import_custom_result_on_table: Union[
        Unset, "TableSqlImportCustomResultCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_checks, Unset):
            custom_checks = self.custom_checks.to_dict()

        profile_sql_condition_failed_on_table: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_sql_condition_failed_on_table, Unset):
            profile_sql_condition_failed_on_table = (
                self.profile_sql_condition_failed_on_table.to_dict()
            )

        profile_sql_condition_passed_percent_on_table: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.profile_sql_condition_passed_percent_on_table, Unset):
            profile_sql_condition_passed_percent_on_table = (
                self.profile_sql_condition_passed_percent_on_table.to_dict()
            )

        profile_sql_aggregate_expression_on_table: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_sql_aggregate_expression_on_table, Unset):
            profile_sql_aggregate_expression_on_table = (
                self.profile_sql_aggregate_expression_on_table.to_dict()
            )

        profile_import_custom_result_on_table: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_import_custom_result_on_table, Unset):
            profile_import_custom_result_on_table = (
                self.profile_import_custom_result_on_table.to_dict()
            )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom_checks is not UNSET:
            field_dict["custom_checks"] = custom_checks
        if profile_sql_condition_failed_on_table is not UNSET:
            field_dict[
                "profile_sql_condition_failed_on_table"
            ] = profile_sql_condition_failed_on_table
        if profile_sql_condition_passed_percent_on_table is not UNSET:
            field_dict[
                "profile_sql_condition_passed_percent_on_table"
            ] = profile_sql_condition_passed_percent_on_table
        if profile_sql_aggregate_expression_on_table is not UNSET:
            field_dict[
                "profile_sql_aggregate_expression_on_table"
            ] = profile_sql_aggregate_expression_on_table
        if profile_import_custom_result_on_table is not UNSET:
            field_dict[
                "profile_import_custom_result_on_table"
            ] = profile_import_custom_result_on_table

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_custom_sql_profiling_checks_spec_custom_checks import (
            TableCustomSqlProfilingChecksSpecCustomChecks,
        )
        from ..models.table_sql_aggregate_expression_check_spec import (
            TableSqlAggregateExpressionCheckSpec,
        )
        from ..models.table_sql_condition_failed_check_spec import (
            TableSqlConditionFailedCheckSpec,
        )
        from ..models.table_sql_condition_passed_percent_check_spec import (
            TableSqlConditionPassedPercentCheckSpec,
        )
        from ..models.table_sql_import_custom_result_check_spec import (
            TableSqlImportCustomResultCheckSpec,
        )

        d = src_dict.copy()
        _custom_checks = d.pop("custom_checks", UNSET)
        custom_checks: Union[Unset, TableCustomSqlProfilingChecksSpecCustomChecks]
        if isinstance(_custom_checks, Unset):
            custom_checks = UNSET
        else:
            custom_checks = TableCustomSqlProfilingChecksSpecCustomChecks.from_dict(
                _custom_checks
            )

        _profile_sql_condition_failed_on_table = d.pop(
            "profile_sql_condition_failed_on_table", UNSET
        )
        profile_sql_condition_failed_on_table: Union[
            Unset, TableSqlConditionFailedCheckSpec
        ]
        if isinstance(_profile_sql_condition_failed_on_table, Unset):
            profile_sql_condition_failed_on_table = UNSET
        else:
            profile_sql_condition_failed_on_table = (
                TableSqlConditionFailedCheckSpec.from_dict(
                    _profile_sql_condition_failed_on_table
                )
            )

        _profile_sql_condition_passed_percent_on_table = d.pop(
            "profile_sql_condition_passed_percent_on_table", UNSET
        )
        profile_sql_condition_passed_percent_on_table: Union[
            Unset, TableSqlConditionPassedPercentCheckSpec
        ]
        if isinstance(_profile_sql_condition_passed_percent_on_table, Unset):
            profile_sql_condition_passed_percent_on_table = UNSET
        else:
            profile_sql_condition_passed_percent_on_table = (
                TableSqlConditionPassedPercentCheckSpec.from_dict(
                    _profile_sql_condition_passed_percent_on_table
                )
            )

        _profile_sql_aggregate_expression_on_table = d.pop(
            "profile_sql_aggregate_expression_on_table", UNSET
        )
        profile_sql_aggregate_expression_on_table: Union[
            Unset, TableSqlAggregateExpressionCheckSpec
        ]
        if isinstance(_profile_sql_aggregate_expression_on_table, Unset):
            profile_sql_aggregate_expression_on_table = UNSET
        else:
            profile_sql_aggregate_expression_on_table = (
                TableSqlAggregateExpressionCheckSpec.from_dict(
                    _profile_sql_aggregate_expression_on_table
                )
            )

        _profile_import_custom_result_on_table = d.pop(
            "profile_import_custom_result_on_table", UNSET
        )
        profile_import_custom_result_on_table: Union[
            Unset, TableSqlImportCustomResultCheckSpec
        ]
        if isinstance(_profile_import_custom_result_on_table, Unset):
            profile_import_custom_result_on_table = UNSET
        else:
            profile_import_custom_result_on_table = (
                TableSqlImportCustomResultCheckSpec.from_dict(
                    _profile_import_custom_result_on_table
                )
            )

        table_custom_sql_profiling_checks_spec = cls(
            custom_checks=custom_checks,
            profile_sql_condition_failed_on_table=profile_sql_condition_failed_on_table,
            profile_sql_condition_passed_percent_on_table=profile_sql_condition_passed_percent_on_table,
            profile_sql_aggregate_expression_on_table=profile_sql_aggregate_expression_on_table,
            profile_import_custom_result_on_table=profile_import_custom_result_on_table,
        )

        table_custom_sql_profiling_checks_spec.additional_properties = d
        return table_custom_sql_profiling_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
